<div align="center">
  <h2>Karbon</h2>
  <h3>Karbon tracks background mouse events and turns them into artistic values!</h3>
  <a href="https://github.com/furkanonder/karbon/issues"><img alt="GitHub issues" src="https://img.shields.io/github/issues/furkanonder/bor"></a>
  <a href="https://github.com/furkanonder/karbon/stargazers"><img alt="GitHub stars" src="https://img.shields.io/github/stars/furkanonder/bor"></a>
  <a href="https://github.com/furkanonder/karbon/blob/main/LICENSE"><img alt="GitHub license" src="https://img.shields.io/github/license/furkanonder/bor"></a>
  <a href="https://pepy.tech/project/karbon"><img alt="Downloads" src="https://pepy.tech/badge/karbon"></a>
</div>


## Installation

```sh
pip install karbon
```

## Running

```sh
karbon
```

### After few hours later...

<div align="center">
  <img src="https://raw.githubusercontent.com/furkanonder/karbon/master/assets/examples/example.jpg" width=900px />
</div>

## Snapshots

You can find the snapshots in the `.karbon_snapshots` folder within your home
directory.
